<?php
/*
*  @author metacreo <metacreo@newestvision.com>
*/

require_once(dirname(__FILE__).'/../../classes/SimpleSecurityAction.php');

class AdminSimpleSecurityActionController extends ModuleAdminController
{
    public function __construct()
    {
        parent::__construct();
        $this->bootstrap = true;
        $this->meta_title = 'Simple Security Actions';
        if (!$this->module->active) {
            Tools::redirectAdmin($this->context->link->getAdminLink('AdminHome'));
        }
        $this->table = 'simplesecurity_action';
        $this->identifier = 'id';
        $this->className = 'SimpleSecurityAction';
        $this->allow_export = true;
        $this->addRowAction('view');
        $this->addRowAction('edit');
        $this->addRowAction('delete');
        $this->list_no_link = true;
        $this->_defaultOrderBy = 'a.id';
        $this->_defaultOrderWay = 'DESC';
        $this->_default_pagination = 20;
        $this->show_toolbar = true;
        $this->bulk_actions = [
            'delete' => [
                'text' => 'Delete selected',
                'confirm' => 'Delete selected items?'
            ]
        ];
        $this->admin_link = $this->context->link->getAdminLink('Admin' . $this->className);
        $this->fields_list = [
            'id' => ['title' => 'ID', 'class' => 'fixed-width-xs', 'align' => 'center'],
            'action' => ['title' => 'Action', 'align' => 'center'],
            'attempt' => ['title' => 'Attempt', 'align' => 'center'],
            'detected' => ['title' => 'Detected', 'align' => 'center'],
            'email' => ['title' => 'Email', 'align' => 'center'],
            'block_email' => [
                'title' => 'Ban Email',
                'align' => 'center',
                'type' => 'text',
                'search' => false,
                'orderby' => false,
                'class' => 'fixed-width-sm',
                'callback' => 'formatBanValues'
            ],
            'password' => ['title' => 'Password', 'align' => 'center'],
            'ip_address' => ['title' => 'IP Address', 'align' => 'center'],
            'block_ip' => [
                'title' => 'Ban IP',
                'align' => 'center',
                'type' => 'text',
                'search' => false,
                'orderby' => false,
                'class' => 'fixed-width-sm',
                'callback' => 'formatBanValues'
            ],
            'date' => ['title' => 'DateTime', 'align' => 'center'],
        ];
    }

    public function initPageHeaderToolbar()
    {
        if ($this->display == 'view' || $this->display == 'edit') {
            $this->page_header_toolbar_btn['back_to_list'] = [
                'href' => $this->admin_link,
                'desc' => 'Back to list',
                'icon' => 'process-icon-back'
            ];
        }
        parent::initPageHeaderToolbar();
    }

    public function initToolbar()
    {
        parent::initToolbar();
        unset( $this->toolbar_btn['new'] );
    }

    public function formatBanValues($value)
    {
        switch ($value) {
            case 0:
                return '<span style="color:green;">No</span>';
            case 1:
                return '<span style="color:red;">Yes</span>';
            case 2:
                return '<span style="color:blue;">Never</span>';
        }
    }

    public function renderForm()
    {
        $this->fields_form = [
            'legend' => [
                'title' => 'Simple Security Action',
                'icon' => 'icon-list-ul'
            ],
            'input' => [
                [
                    'name' => 'block_ip',
                    'type' => 'radio',
                    'label' => 'Ban IP',
                    'desc' => 'Block IP Address',
                    'values' => [
                        ['id' => 'block_ip_no', 'value' => 0, 'label' => '<span style="color:green;">No</span>'],
                        ['id' => 'block_ip_yes', 'value' => 1, 'label' => '<span style="color:red;">Yes</span>'],
                        ['id' => 'block_ip_never', 'value' => 2, 'label' => '<span style="color:blue;">Never</span>']
                    ]
                ],
                [
                    'name' => 'block_email',
                    'type' => 'radio',
                    'label' => 'Ban Email',
                    'desc' => 'Block Email Address',
                    'values' => [
                        ['id' => 'block_email_no', 'value' => 0, 'label' => '<span style="color:green;">No</span>'],
                        ['id' => 'block_email_yes', 'value' => 1, 'label' => '<span style="color:red;">Yes</span>'],
                        ['id' => 'block_email_never', 'value' => 2, 'label' => '<span style="color:blue;">Never</span>']
                    ]
                ],
                [
                    'name' => 'action',
                    'type' => 'hidden',
                    'label' => 'Action',
                    'desc' => 'Customer Action'
                ],
                [
                    'name' => 'attempt',
                    'type' => 'hidden',
                    'label' => 'Attempt',
                    'desc' => 'Attempt Number'
                ],
                [
                    'name' => 'detected',
                    'type' => 'hidden',
                    'label' => 'Detected',
                    'desc' => 'Detected Violation'
                ],
                [
                    'name' => 'email',
                    'type' => 'text',
                    'label' => 'Email',
                    'desc' => 'Email Address',
                    'disabled' => true
                ],
                [
                    'name' => 'password',
                    'type' => 'hidden',
                    'label' => 'Password',
                    'desc' => 'Customer Password'
                ],
                [
                    'name' => 'ip_address',
                    'type' => 'text',
                    'label' => 'IP Address',
                    'desc' => 'Customer IP Address',
                    'disabled' => true
                ],
                [
                    'name' => 'referer',
                    'type' => 'hidden',
                    'label' => 'Referer',
                    'desc' => 'HTTP Referer'
                ],
                [
                    'name' => 'user_agent',
                    'type' => 'hidden',
                    'label' => 'User Agent',
                    'desc' => 'HTTP User Agent'
                ],
                [
                    'name' => 'accept',
                    'type' => 'hidden',
                    'label' => 'Accept Header',
                    'desc' => 'HTTP Accept Header'
                ],
                [
                    'name' => 'accept_lang',
                    'type' => 'hidden',
                    'label' => 'Accept Lang Header',
                    'desc' => 'HTTP Accept Lang Header'
                ],
                [
                    'name' => 'cookie',
                    'type' => 'hidden',
                    'label' => 'Cookie',
                    'desc' => 'HTTP Cookie'
                ],
                [
                    'name' => 'date',
                    'type' => 'text',
                    'label' => 'DateTime',
                    'desc' => 'Connection DateTime',
                    'disabled' => true
                ]
            ],
            'submit' => [
                'title' => 'Save'
            ]
        ];
        return parent::renderForm();
    }

    public function renderView()
    {
        $object = new SimpleSecurityAction($this->id_object);
        $this->context->smarty->assign(['action' => $object]);
        $tpl = $this->context->smarty->createTemplate('module:simplesecurity/views/templates/admin/action-view.tpl');
        return $tpl->fetch();
    }

    public function initContent()
    {
        if (Tools::getIsset('empty_table')) {
            $this->emptyTable();
        }
        $this->context->smarty->assign(['module_dir' => _MODULE_DIR_ . $this->module->name . '/']);
        $tpl = $this->context->smarty->createTemplate('module:simplesecurity/views/templates/admin/action.tpl');
        $this->content = $tpl->fetch();
        return parent::initContent();
    }

    private function emptyTable()
    {
        Db::getInstance()->execute('TRUNCATE TABLE `' . _DB_PREFIX_ . $this->module->name . '_action`');
    }

}
