<?php
/*
*  @author metacreo <metacreo@newestvision.com>
*/

require_once(dirname(__FILE__).'/../../classes/SimpleSecurityTrigger.php');

class AdminSimpleSecurityTriggerController extends ModuleAdminController
{
    public function __construct()
    {
        parent::__construct();
        $this->bootstrap = true;
        $this->meta_title = 'Simple Security Triggers';
        if (!$this->module->active) {
            Tools::redirectAdmin($this->context->link->getAdminLink('AdminHome'));
        }
        $this->table = 'simplesecurity_trigger';
        $this->identifier = 'id';
        $this->className = 'SimpleSecurityTrigger';
        $this->allow_export = true;
        $this->_defaultOrderBy = 'a.id';
        $this->_defaultOrderWay = 'DESC';
        $this->_default_pagination = 20;
        $this->addRowAction('edit');
        $this->addRowAction('delete');
        $this->bulk_actions = [
            'delete' => [
                'text' => 'Delete selected',
                'confirm' => 'Delete selected items?'
            ]
        ];
        $this->list_no_link = true;
        $this->fields_list = [
            'id' => ['title' => 'ID', 'class' => 'fixed-width-xs', 'align' => 'center'],
            'words' => ['title' => 'Words', 'align' => 'center'],
        ];
    }

    public function renderForm()
    {
        $this->fields_form = [
            'legend' => [
                'title' => 'Simple Security Trigger',
                'icon' => 'icon-list-ul'
            ],
            'input' => [
                [
                    'type'     => 'text',
                    'label'    => 'Words',
                    'name'     => 'words',
                    'size'     => 20,
                    'required' => true
                ]
            ],
            'submit' => [
                'title' => 'Save',
            ]
        ];
        return parent::renderForm();
    }

    public function initContent()
    {
        if (Tools::getIsset('empty_table')) {
            $this->emptyTable();
        }
        $this->context->smarty->assign(['module_dir' => _MODULE_DIR_ . $this->module->name . '/']);
        $tpl = $this->context->smarty->createTemplate('module:simplesecurity/views/templates/admin/trigger.tpl');
        $this->content = $tpl->fetch();
        return parent::initContent();
    }

    private function emptyTable()
    {
        Db::getInstance()->execute('TRUNCATE TABLE `' . _DB_PREFIX_ . $this->module->name . '_trigger`');
    }

    public function postProcess()
    {
        if (!$this->ajax) {
            if (isset($_POST['words'])) {
                $_POST['words'] = strtolower($_POST['words']);
            }
        }
        parent::postProcess();
    }
}
